@@ -52,7 +52,7 @@ class Exceptions:
 
 class IoTDeviceAdvisorClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -61,8 +61,8 @@ class IoTDeviceAdvisorClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_suite_definition(
@@ -71,14 +71,14 @@ class IoTDeviceAdvisorClient:
         tags: Dict[str, str] = None,
     ) -> CreateSuiteDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.create_suite_definition)
-        [Show boto3-stubs documentation](./client.md#create-suite-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.create_suite_definition)
+        [Show boto3-stubs documentation](./client.md#create_suite_definition)
         """
 
     def delete_suite_definition(self, suiteDefinitionId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.delete_suite_definition)
-        [Show boto3-stubs documentation](./client.md#delete-suite-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.delete_suite_definition)
+        [Show boto3-stubs documentation](./client.md#delete_suite_definition)
         """
 
     def generate_presigned_url(
@@ -89,38 +89,38 @@ class IoTDeviceAdvisorClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_suite_definition(
         self, suiteDefinitionId: str, suiteDefinitionVersion: str = None
     ) -> GetSuiteDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_definition)
-        [Show boto3-stubs documentation](./client.md#get-suite-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_definition)
+        [Show boto3-stubs documentation](./client.md#get_suite_definition)
         """
 
     def get_suite_run(self, suiteDefinitionId: str, suiteRunId: str) -> GetSuiteRunResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run)
-        [Show boto3-stubs documentation](./client.md#get-suite-run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run)
+        [Show boto3-stubs documentation](./client.md#get_suite_run)
         """
 
     def get_suite_run_report(
         self, suiteDefinitionId: str, suiteRunId: str
     ) -> GetSuiteRunReportResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run_report)
-        [Show boto3-stubs documentation](./client.md#get-suite-run-report)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.get_suite_run_report)
+        [Show boto3-stubs documentation](./client.md#get_suite_run_report)
         """
 
     def list_suite_definitions(
         self, maxResults: int = None, nextToken: str = None
     ) -> ListSuiteDefinitionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_definitions)
-        [Show boto3-stubs documentation](./client.md#list-suite-definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_definitions)
+        [Show boto3-stubs documentation](./client.md#list_suite_definitions)
         """
 
     def list_suite_runs(
@@ -131,22 +131,22 @@ class IoTDeviceAdvisorClient:
         nextToken: str = None,
     ) -> ListSuiteRunsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_runs)
-        [Show boto3-stubs documentation](./client.md#list-suite-runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_suite_runs)
+        [Show boto3-stubs documentation](./client.md#list_suite_runs)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def list_test_cases(
         self, intendedForQualification: bool = None, maxResults: int = None, nextToken: str = None
     ) -> ListTestCasesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_test_cases)
-        [Show boto3-stubs documentation](./client.md#list-test-cases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.list_test_cases)
+        [Show boto3-stubs documentation](./client.md#list_test_cases)
         """
 
     def start_suite_run(
@@ -157,20 +157,20 @@ class IoTDeviceAdvisorClient:
         tags: Dict[str, str] = None,
     ) -> StartSuiteRunResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.start_suite_run)
-        [Show boto3-stubs documentation](./client.md#start-suite-run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.start_suite_run)
+        [Show boto3-stubs documentation](./client.md#start_suite_run)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_suite_definition(
@@ -179,6 +179,6 @@ class IoTDeviceAdvisorClient:
         suiteDefinitionConfiguration: "SuiteDefinitionConfigurationTypeDef" = None,
     ) -> UpdateSuiteDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.update_suite_definition)
-        [Show boto3-stubs documentation](./client.md#update-suite-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iotdeviceadvisor.html#IoTDeviceAdvisor.Client.update_suite_definition)
+        [Show boto3-stubs documentation](./client.md#update_suite_definition)
         """
