@@ -6,9 +6,9 @@ Type annotations for iotdeviceadvisor service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_iotdeviceadvisor.literals import Status
+    from mypy_boto3_iotdeviceadvisor.literals import StatusType
 
-    data: Status = "CANCELED"
+    data: StatusType = "CANCELED"
     ```
 """
 import sys
@@ -19,10 +19,12 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("Status", "SuiteRunStatus")
+__all__ = ("StatusType", "SuiteRunStatusType")
 
 
-Status = Literal["CANCELED", "ERROR", "FAIL", "PASS", "PASS_WITH_WARNINGS", "PENDING", "RUNNING"]
-SuiteRunStatus = Literal[
+StatusType = Literal[
+    "CANCELED", "ERROR", "FAIL", "PASS", "PASS_WITH_WARNINGS", "PENDING", "RUNNING"
+]
+SuiteRunStatusType = Literal[
     "CANCELED", "ERROR", "FAIL", "PASS", "PASS_WITH_WARNINGS", "PENDING", "RUNNING"
 ]
