@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
-from .literals import Status, SuiteRunStatus
+from .literals import StatusType, SuiteRunStatusType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -101,7 +101,7 @@ GetSuiteRunResponseTypeDef = TypedDict(
         "testResult": "TestResultTypeDef",
         "startTime": datetime,
         "endTime": datetime,
-        "status": SuiteRunStatus,
+        "status": SuiteRunStatusType,
         "errorReason": str,
         "tags": Dict[str, str],
     },
@@ -209,7 +209,7 @@ SuiteRunInformationTypeDef = TypedDict(
         "createdAt": datetime,
         "startedAt": datetime,
         "endAt": datetime,
-        "status": SuiteRunStatus,
+        "status": SuiteRunStatusType,
         "passed": int,
         "failed": int,
     },
@@ -240,7 +240,7 @@ TestCaseRunTypeDef = TypedDict(
         "testCaseRunId": str,
         "testCaseDefinitionId": str,
         "testCaseDefinitionName": str,
-        "status": Status,
+        "status": StatusType,
         "startTime": datetime,
         "endTime": datetime,
         "logUrl": str,
